A proposition made up of the disjunction of possibly negated terms.
For example the proposition p \/ ~q \/ r would be represetnted as the
following.
let clause = resolution_prover::Clause {
parts: vec!(
resolution_prover::ClausePart::Term("p".to_string()),
resolution_prover::ClausePart::NegatedTerm("q".to_string()),
resolution_prover::ClausePart::Term("r".to_string())
)
};
Converts the given proposition into the corresponding clauses. Note
that one proposition could break down into one or more clauses.
let prop1 = resolution_prover::term("hello".to_string());
let expected = vec!(resolution_prover::Clause {
parts: vec!(
resolution_prover::ClausePart::Term("hello".to_string())
)
});
assert_eq!(
resolution_prover::Clause::from_proposition(prop1),
expected
);
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Feeds this value into the given [Hasher]. Read more
Feeds a slice of this type into the given [Hasher]. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.